@@ -19,7 +19,24 @@ class AsyncToSerialHelper:
 
     def _add_to_loop(self, coro: Coroutine):
         """ Add coro to event loop via run_until_complete """
-        return self._loop.run_until_complete(coro)
+        try:
+            return self._loop.run_until_complete(coro)
+
+        except RuntimeError as e:
+            try:
+                # `RuntimeError: This event loop is already running` thrown by jupyter notebook
+                # See hydrotools #99 for context and notebook #3397 for detail
+                import nest_asyncio
+
+                nest_asyncio.apply()
+
+                return self._loop.run_until_complete(coro)
+            except ModuleNotFoundError:
+                error_message = (
+                    "nest_asycnio package not found. Install using `pip install nest_asycnio`.\n"
+                    "See https://github.com/NOAA-OWP/hydrotools/issues/99 for more detail."
+                )
+                raise ModuleNotFoundError(error_message) from e
 
     def _wrap_func_in_coro(self, func: Callable, *args, **kwargs):
         """ Create partial func; wrap and call partial in coro; return coro """
